==> plantuml-libs-9.0.0.tgz: package/distribution/simpleicons-7/M/Metrodelaciudaddemexico.md <==
# Metrodelaciudaddemexico


```text
simpleicons-7/M/Metrodelaciudaddemexico
```

```text
include('simpleicons-7/M/Metrodelaciudaddemexico')
```



| Illustration | Metrodelaciudaddemexico |
| :---: | :---: |
| ![illustration for Illustration](../../simpleicons-7/M/Metrodelaciudaddemexico.png) | ![illustration for Metrodelaciudaddemexico](../../simpleicons-7/M/Metrodelaciudaddemexico.Local.png) |




## Metrodelaciudaddemexico

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Metrodelaciudaddemexico
include('simpleicons-7/M/Metrodelaciudaddemexico')

' renders the element
Metrodelaciudaddemexico('Metrodelaciudaddemexico', 'Metrodelaciudaddemexico', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Metrodelaciudaddemexico
include('simpleicons-7/M/Metrodelaciudaddemexico')

' renders the element
Metrodelaciudaddemexico('Metrodelaciudaddemexico', 'Metrodelaciudaddemexico', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/simpleicons-7/M/Metrodelaciudaddemexico.md <==
# Metrodelaciudaddemexico


```text
simpleicons-7/M/Metrodelaciudaddemexico
```

```text
include('simpleicons-7/M/Metrodelaciudaddemexico')
```



| Illustration | Metrodelaciudaddemexico |
| :---: | :---: |
| ![illustration for Illustration](../../simpleicons-7/M/Metrodelaciudaddemexico.png) | ![illustration for Metrodelaciudaddemexico](../../simpleicons-7/M/Metrodelaciudaddemexico.Local.png) |




## Metrodelaciudaddemexico

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Metrodelaciudaddemexico
include('simpleicons-7/M/Metrodelaciudaddemexico')

' renders the element
Metrodelaciudaddemexico('Metrodelaciudaddemexico', 'Metrodelaciudaddemexico', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Metrodelaciudaddemexico
include('simpleicons-7/M/Metrodelaciudaddemexico')

' renders the element
Metrodelaciudaddemexico('Metrodelaciudaddemexico', 'Metrodelaciudaddemexico', 'an optional tech label', 'an optional description')
@enduml
```
